if __name__ == "__main__":
    print(
        "Type annotations for boto3.Snowball 1.16.53\n"
        "Version:         1.16.53.0\n"
        "Builder version: 4.3.1\n"
        "Docs:            https://pypi.org/project/mypy-boto3-snowball/\n"
        "Other services:  https://pypi.org/project/boto3-stubs/\n"
        "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
    )
